@@ -13,11 +13,16 @@
 
 #' @title Plot annual summary statistics for data screening
 #'
-#' @description Plots the mean, median, maximum, minimum, standard deviation of annual flows. Calculates statistics
-#'    from all values, unless specified. Data calculated using \code{screen_flow_data()} function. Returns a list of plots.
+#' @description Plots the mean, median, maximum, minimum, standard deviation of annual flows and indicates data availability. 
+#'     Calculates statistics from all values, unless specified. Data calculated using \code{screen_flow_data()} function. 
+#'     Returns a list of plots.
 #'
 #' @inheritParams screen_flow_data
 #' @inheritParams plot_annual_stats
+#' @param include_stats Vector of one or all of \code{c("Mean", "Median", "Minimum", "Maximum", "Standard Deviation")} to list
+#'    annual summary statistics to plot for screening. Default all.
+#' @param plot_availability Logical value specifying whether to indicate if years contain complete data or missing values.
+#'    Default \code{TRUE}. Use \code{FALSE} for original fasstr version.
 #'
 #' @return A list of ggplot2 objects with the following for each station provided:
 #'   \item{Data_Screening}{a plot that contains annual summary statistics for screening}
@@ -65,7 +70,9 @@ plot_data_screening <- function(data,
                                 months = 1:12,
                                 start_year,
                                 end_year,
-                                include_title = FALSE){ 
+                                include_title = FALSE,
+                                plot_availability = TRUE,
+                                include_stats = c("Mean", "Median", "Minimum", "Maximum", "Standard Deviation")){ 
   
   
   ## ARGUMENT CHECKS
@@ -83,8 +90,14 @@ plot_data_screening <- function(data,
   if (missing(end_year)) {
     end_year <- 9999
   }
+  if (length(plot_availability) > 1)   stop("Only one plot_availability logical value can be listed.", call. = FALSE)
+  if (!is.logical(plot_availability))  stop("plot_availability argument must be logical (TRUE/FALSE).", call. = FALSE)
+  
+  if (!any(c("Mean", "Median", "Minimum", "Maximum", "Standard Deviation") %in% include_stats)) 
+      stop("include_stats must be one or all of c('Mean', 'Median', 'Minimum', 'Maximum', 'Standard Deviation').", call. = FALSE)
+  include_stats <- include_stats[include_stats %in% c("Mean", "Median", "Minimum", "Maximum", "Standard Deviation")]
 
-  include_title_checks(include_title)
+  logical_arg_check(include_title)
     
   ## FLOW DATA CHECKS AND FORMATTING
   ## -------------------------------
@@ -109,11 +122,13 @@ plot_data_screening <- function(data,
                                    water_year_start = water_year_start,
                                    start_year = start_year,
                                    end_year = end_year,
-                                   months = months)
-  
-  flow_summary <- dplyr::select(flow_summary, STATION_NUMBER, Year, Minimum, Maximum, Mean, "Standard Deviation" = StandardDeviation)
-  flow_summary <- tidyr::gather(flow_summary, Statistic, Value, 3:6)
+                                   months = months,
+                                   include_symbols = FALSE)
   
+  flow_summary <- dplyr::select(flow_summary, STATION_NUMBER, Year, Minimum, Maximum, Mean, Median, "Standard Deviation" = StandardDeviation, n_missing_Q)
+  flow_summary <- dplyr::mutate(flow_summary, n_missing_Q = ifelse(n_missing_Q == 0, "Complete", "Missing Values"))
+  flow_summary <- tidyr::gather(flow_summary, Statistic, Value, 3:7)
+  flow_summary <- dplyr::filter(flow_summary, Statistic %in% include_stats)
   
   ## PLOT STATS
   ## ----------
@@ -122,22 +137,27 @@ plot_data_screening <- function(data,
   y_axis_title <- ifelse(as.character(substitute(values)) == "Volume_m3", "Volume (cubic metres)", #expression(Volume~(m^3))
                          ifelse(as.character(substitute(values)) == "Yield_mm", "Yield (mm)", 
                                 "Discharge (cms)")) #expression(Discharge~(m^3/s))
-  
+
   # Plot
   sum_plots <- dplyr::group_by(flow_summary, STATION_NUMBER)
   sum_plots <- tidyr::nest(sum_plots)
   sum_plots <- dplyr::mutate(sum_plots,
-                                plot = purrr::map2(data, STATION_NUMBER, 
+                                plot = purrr::map2(data, STATION_NUMBER,
          ~ggplot2::ggplot(data = ., ggplot2::aes(x = Year, y = Value)) +
            ggplot2::geom_line(colour = "dodgerblue4", na.rm = TRUE) +
-           ggplot2::geom_point(colour = "firebrick3", na.rm = TRUE) +
+           {if (!plot_availability) ggplot2::geom_point(colour = "firebrick3", na.rm = TRUE, size = 2) }+
+           {if (plot_availability) ggplot2::geom_point(ggplot2::aes(shape = n_missing_Q), colour = "firebrick3", na.rm = TRUE, size =2) }+
            ggplot2::facet_wrap(~Statistic, ncol = 2, scales = "free_y", strip.position = "top") +
            ggplot2::scale_x_continuous(breaks = scales::pretty_breaks(n = 8))+
            {if(length(unique(flow_summary$Year)) < 5) ggplot2::scale_x_continuous(breaks = unique(flow_summary$Year))}+
-           ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6)) +
+           ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 6),
+                                       labels = scales::label_number(scale_cut = scales::cut_short_scale())) +
+           {if (plot_availability) ggplot2::scale_shape_manual(values = c(19,21),
+                                       labels = c("Complete Data", "Missing Values"),
+                                       name = "Data Availability") } + 
            ggplot2::expand_limits(y = 0) +
            ggplot2::ylab(y_axis_title) +
-           ggplot2::xlab("Year") +
+           ggplot2::xlab(ifelse(water_year_start ==1, "Year", "Water Year"))+
            ggplot2::theme_bw() +
            {if (include_title & .y != "XXXXXXX") ggplot2::ggtitle(paste(.y)) } +
            ggplot2::theme(panel.border = ggplot2::element_rect(colour = "black", fill = NA, size = 1),
@@ -148,7 +168,7 @@ plot_data_screening <- function(data,
                           strip.background = ggplot2::element_blank(),
                           strip.text = ggplot2::element_text(hjust = 0, face = "bold", size = 10))
                                 ))
-  
+
   # Create a list of named plots extracted from the tibble
   plots <- sum_plots$plot
   if (nrow(sum_plots) == 1) {
@@ -156,7 +176,7 @@ plot_data_screening <- function(data,
   } else {
     names(plots) <- paste0(sum_plots$STATION_NUMBER, "_Data_Screening")
   }
-  
+
   plots
   
 }
