@@ -3,7 +3,7 @@ context("Screen flow data")
 test_that("creates a dataframe with the proper columns", {
   skip_on_cran()
   skip_on_ci()
-  data <- screen_flow_data(station_number = "08NM116")
+  data <- screen_flow_data(station_number = "08NM116", include_symbols = FALSE)
   expect_true(is.data.frame(data) &
                 ncol(data) == 22 &
                 all(c("Year","n_days","n_Q","n_missing_Q","Minimum","Jan_missing_Q") %in% colnames(data)))
@@ -12,7 +12,7 @@ test_that("creates a dataframe with the proper columns", {
 test_that("outputs data for two stations", {
   skip_on_cran()
   skip_on_ci()
-  data <- screen_flow_data(station_number = c("08NM116","08HB048"))
+  data <- screen_flow_data(station_number = c("08NM116","08HB048"), include_symbols = FALSE)
   expect_true(length(unique(data$STATION_NUMBER)) == 2)
 })
 
@@ -21,7 +21,8 @@ test_that("data is filtered by years properly", {
   skip_on_ci()
   data <- screen_flow_data(station_number = "08NM116",
                            start_year = 1981,
-                           end_year = 2010)
+                           end_year = 2010,
+                           include_symbols = FALSE)
   expect_identical(1981, min(data$Year))
   expect_identical(2010, max(data$Year))
 })
@@ -41,7 +42,8 @@ test_that("data is summarized by water years properly", {
   
   data <- screen_flow_data(data = flow_data,
                            start_year = 1981,
-                           water_year_start = 10)
+                           water_year_start = 10, 
+                           include_symbols = FALSE)
   data <- dplyr::filter(data, Year == 1981)
   data <- dplyr::select(data, Mean, Median, Maximum, Minimum)
   
@@ -57,7 +59,7 @@ test_that("missing dates are calculated properly", {
                                 sum = sum(is.na(Value)))
   test_data <- tidyr::spread(test_data, MonthName, sum)
 
-  data <- screen_flow_data(station_number = "08NM116")
+  data <- screen_flow_data(station_number = "08NM116", include_symbols = FALSE)
   
   expect_equal(test_data$Jan, data$Jan_missing_Q)
 })
@@ -78,7 +80,8 @@ test_that("data is filtered by months properly", {
   
   data <- screen_flow_data(data = flow_data,
                            start_year = 1981,
-                           months = 7:9)
+                           months = 7:9,
+                           include_symbols = FALSE)
   data_test <- dplyr::filter(data, Year == 1981)
   data_test <- dplyr::select(data_test, Mean, Median, Maximum, Minimum)
   
@@ -90,7 +93,7 @@ test_that("transpose properly transposed the results", {
   skip_on_cran()
   skip_on_ci()
   data <- screen_flow_data(station_number = "08NM116",
-                           transpose = TRUE)
+                           transpose = TRUE, include_symbols = FALSE)
   expect_true(all(c("n_days","n_Q","n_missing_Q","Minimum","Jan_missing_Q") %in% data$Statistic))
 })
 
